TESTE

Dependencies:   TextLCD mbed

Files at this revision

API Documentation at this revision

Comitter:
henriquer
Date:
Fri Nov 18 12:29:44 2022 +0000
Parent:
4:a3e4bb2053cb
Commit message:
TESTE LCD

Changed in this revision

main.cpp Show annotated file Show diff for this revision Revisions of this file
--- a/main.cpp	Sun Mar 29 13:12:07 2015 +0000
+++ b/main.cpp	Fri Nov 18 12:29:44 2022 +0000
@@ -7,16 +7,16 @@
 Serial pc(USBTX, USBRX); // tx, rx
  
 // I2C Communication
-I2C i2c_lcd(p9,p10); // SDA, SCL
+I2C i2c_lcd(D15,D14); // SDA, SCL
 //I2C i2c_lcd(p28,p27); // SDA, SCL
  
 // SPI Communication
-SPI spi_lcd(p5, NC, p7); // MOSI, MISO, SCLK
+//SPI spi_lcd(p5, NC, p7); // MOSI, MISO, SCLK
 
 // LCD instantiation 
 //TextLCD lcd(p15, p16, p17, p18, p19, p20, TextLCD::LCD20x2);        // 4bit bus: rs, e, d4-d7
-TextLCD_I2C lcd(&i2c_lcd, 0x40, TextLCD::LCD20x4);                  // I2C exp: I2C bus, PCF8574 Slaveaddress, LCD Type
-//TextLCD_I2C lcd(&i2c_lcd, 0x42, TextLCD::LCD16x2, TextLCD::WS0010); // I2C exp: I2C bus, PCF8574 Slaveaddress, LCD Type, Ctrl Type
+TextLCD_I2C lcd(&i2c_lcd, 0x7E, TextLCD::LCD20x4);                  // I2C exp: I2C bus, PCF8574 Slaveaddress, LCD Type
+//TextLCD_I2C lcd(&i2c_lcd, 0x7E, TextLCD::LCD16x2, TextLCD::HD44780); // I2C exp: I2C bus, PCF8574 Slaveaddress, LCD Type, Ctrl Type
 //TextLCD_I2C lcd(&spi_lcd, p8, TextLCD::LCD24x4D);                   // I2C exp: SPI bus, CS pin, LCD Type
 //TextLCD_SPI_N lcd(&spi_lcd, p8, p9, TextLCD::LCD16x2, NC, TextLCD::ST7032_3V3); // SPI native: SPI bus, CS pin, RS pin, LCDType=LCD16x2, BL=NC, LCDTCtrl=ST7032
 //TextLCD_I2C_N lcd(&i2c_lcd, ST7032_SA, TextLCD::LCD16x2, NC, TextLCD::ST7032_3V3); // I2C native: I2C bus, slaveaddress, LCDType=LCD16x2, BL=NC, LCDTCtrl=ST7032 =Ok